==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/widget/new_terminal_item.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class BankBoxTerminalItemWidget extends StatelessWidget {
  final TerminalModel terminal;
  const BankBoxTerminalItemWidget({super.key, required this.terminal});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () {
        pushRoute(
            context,
            TerminalInfoScreen(
              model: terminal,
            ));
      },
      child: Container(
          margin: const EdgeInsets.symmetric(vertical: 8),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 16),
          width: double.infinity,
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(16),
              color: pluginTheme.getFGColor,
              boxShadow: pluginTheme.isLightTheme
                  ? const [
                      BoxShadow(
                          color: Color(0xFFE9E9E9),
                          spreadRadius: 1,
                          blurRadius: 14)
                    ]
                  : null),
          child: Column(
            children: [
              Row(
                children: [
                  Container(
                      height: 40,
                      width: 40,
                      padding: const EdgeInsets.only(top: 8),
                      decoration: BoxDecoration(
                          color: AppColors.ravenGrey4.withOpacity(0.5),
                          shape: BoxShape.circle),
                      child: Image.asset(loadAsset("bankbox_icon.png"))),
                  const Gap(12),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Hero(
                        tag: terminal.tid ?? "",
                        child: Text((terminal.tidLabel ?? "").toUpperCase(),
                            style: headling1.copyWith(
                                fontSize: 16, fontWeight: FontWeight.w800)),
                      ),
                      const Gap(2),
                      Text("Serial: ${terminal.serial ?? ""}",
                          style: subtitle.copyWith(
                              fontWeight: FontWeight.w600,
                              fontSize: 12,
                              color: AppColors.ravenGreyLight1))
                    ],
                  )
                ],
              ),
              const Gap(12),
              Container(
                padding:
                    const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(6),
                    color: AppColors.ravenGrey4
                        .withOpacity(pluginTheme.isLightTheme ? 0.4 : 0.08)),
                child: Row(children: [
                  ItemWidget(
                    name: "CASH IN",
                    value: terminal.cashIn ?? 0,
                  ),
                ]),
              )
            ],
          )),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final double value;
  const ItemWidget({super.key, required this.name, required this.value});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w600,
                fontSize: 12,
                color: AppColors.lightTextColor)),
        const Gap(2),
        RavenPayMoneyWidget(
          amount: value.toString(),
          fontSize: 16,
        )
      ],
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/widget/new_terminal_item.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

class BankBoxTerminalItemWidget extends StatelessWidget {
  final TerminalModel terminal;
  const BankBoxTerminalItemWidget({super.key, required this.terminal});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () {
        pushRoute(
            context,
            TerminalInfoScreen(
              model: terminal,
            ));
      },
      child: Container(
          margin: const EdgeInsets.symmetric(vertical: 8),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 16),
          width: double.infinity,
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(16),
              color: pluginTheme.getFGColor,
              boxShadow: pluginTheme.isLightTheme
                  ? const [
                      BoxShadow(
                          color: Color(0xFFE9E9E9),
                          spreadRadius: 1,
                          blurRadius: 14)
                    ]
                  : null),
          child: Column(
            children: [
              Row(
                children: [
                  Container(
                      height: 40,
                      width: 40,
                      padding: const EdgeInsets.only(top: 8),
                      decoration: BoxDecoration(
                          color: AppColors.ravenGrey4.withOpacity(0.5),
                          shape: BoxShape.circle),
                      child: Image.asset(loadAsset("bankbox_icon.png"))),
                  const Gap(12),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Hero(
                        tag: terminal.tid ?? "",
                        child: Text((terminal.tidLabel ?? "").toUpperCase(),
                            style: headling1.copyWith(
                                fontSize: 16, fontWeight: FontWeight.w800)),
                      ),
                      const Gap(2),
                      Text("Serial: ${terminal.serial ?? ""}",
                          style: subtitle.copyWith(
                              fontWeight: FontWeight.w600,
                              fontSize: 12,
                              color: AppColors.ravenGreyLight1))
                    ],
                  )
                ],
              ),
              const Gap(12),
              Container(
                padding:
                    const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(6),
                    color: AppColors.ravenGrey4
                        .withOpacity(pluginTheme.isLightTheme ? 0.4 : 0.08)),
                child: Row(children: [
                  ItemWidget(
                    name: "CASH IN",
                    value: terminal.cashIn ?? 0,
                  ),
                ]),
              )
            ],
          )),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final double value;
  const ItemWidget({super.key, required this.name, required this.value});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w600,
                fontSize: 12,
                color: AppColors.lightTextColor)),
        const Gap(2),
        RavenPayMoneyWidget(
          amount: value.toString(),
          fontSize: 16,
        )
      ],
    );
  }
}
